==> wireshark_1.10.6.orig.tar.bz2: wireshark-1.10.6/epan/wmem/wmem_stack.c <==
/* wmem_stack.c
 * Wireshark Memory Manager Stack
 * Copyright 2012, Evan Huus <eapache@gmail.com>
 *
 * $Id$
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
 * Copyright 1998 Gerald Combs
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include <string.h>
#include <glib.h>

#include "wmem_core.h"
#include "wmem_stack.h"
#include "wmem_slist.h"

/* Wmem stack is implemented as a simple wrapper over Wmem slist */

void *
wmem_stack_peek(const wmem_stack_t *stack)
{
    wmem_slist_frame_t *frame;

    frame = wmem_slist_front(stack);

    g_assert(frame);

    return wmem_slist_frame_data(frame);
}

void *
wmem_stack_pop(wmem_stack_t *stack)
{
    void *data;

    data = wmem_stack_peek(stack);

    wmem_slist_remove(stack, data);

    return data;
}

void
wmem_stack_push(wmem_stack_t *stack, void *data)
{
    wmem_slist_prepend(stack, data);
}

/*
 * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
 *
 * Local variables:
 * c-basic-offset: 4
 * tab-width: 8
 * indent-tabs-mode: nil
 * End:
 *
 * vi: set shiftwidth=4 tabstop=8 expandtab:
 * :indentSize=4:tabSize=8:noTabs=true:
 */

==> wireshark-1.11.1.tar.bz2: wireshark-1.11.1/epan/wmem/wmem_stack.c <==
/* wmem_stack.c
 * Wireshark Memory Manager Stack
 * Copyright 2012, Evan Huus <eapache@gmail.com>
 *
 * $Id: wmem_stack.c 50769 2013-07-21 21:13:30Z eapache $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
 * Copyright 1998 Gerald Combs
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include <string.h>
#include <glib.h>

#include "wmem_core.h"
#include "wmem_stack.h"
#include "wmem_list.h"

/* Wmem stack is implemented as a simple wrapper over Wmem list */

void *
wmem_stack_peek(const wmem_stack_t *stack)
{
    wmem_list_frame_t *frame;

    frame = wmem_list_head(stack);

    g_assert(frame);

    return wmem_list_frame_data(frame);
}

void *
wmem_stack_pop(wmem_stack_t *stack)
{
    void *data;

    data = wmem_stack_peek(stack);

    wmem_list_remove(stack, data);

    return data;
}

/*
 * Editor modelines  -  http://www.wireshark.org/tools/modelines.html
 *
 * Local variables:
 * c-basic-offset: 4
 * tab-width: 8
 * indent-tabs-mode: nil
 * End:
 *
 * vi: set shiftwidth=4 tabstop=8 expandtab:
 * :indentSize=4:tabSize=8:noTabs=true:
 */
